#
# spec file for package gnome-common
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-common
Version:        3.18.0
Release:        3.16
Summary:        Common Files to Build GNOME
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            http://www.gnome.org/
Source:         http://download.gnome.org/sources/gnome-common/3.18/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
Requires:       autoconf
# we need autoconf-archive >= 2014.10.15, as this is when ax_check_enable_debug.m4 and ax_code_coverage.m4 became part of it.
Requires:       autoconf-archive >= 2014.10.15
Requires:       automake
Requires:       gettext-tools
# Avoiding pkgconfig()-style because we want glib-gettextize
Requires:       glib2-devel
Requires:       gtk-doc
Requires:       intltool
Requires:       libtool
Requires:       pkgconfig
Requires:       yelp-tools
BuildArch:      noarch

%description
Gnome-common includes files used by to build GNOME and GNOME applications.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
# the files ax_check_enable_debug.m4 and ax_code_coverage.m4 live in autoconf-archive
rm %{buildroot}%{_datadir}/aclocal/{ax_check_enable_debug,ax_code_coverage}.m4

%files
%doc ChangeLog
%{_bindir}/gnome-autogen.sh
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/gnome-code-coverage.m4
%{_datadir}/aclocal/gnome-common.m4
%{_datadir}/aclocal/gnome-compiler-flags.m4

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon May  2 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Bugs fixed: bgo#747920, bgo#748394, bgo#729406, bgo#729407,
    bgo#741891, bgo#741558, bgo#729931, bgo#735416.
- Drop pgnome-doc-utils-devel BuildRequires: no longer needed.
* Wed Nov  5 2014 dimstar@opensuse.org
- Add autoconf-archive Requires: the files ax_check_enable_debug.m4
  and ax_code_coverage.m4 are now shipped by ac-archive and from
  a GNOME perspective, those two files are mandatory to be present
  for a bootstrap.
- Remove ax_check_enable_debug.m4 and ax_code_coverage.m4 from
  gnome-common installation.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + macros2:
  - Update links to macros in the autoconf-archive.
  - Add support for APPSTREAM_XML macro (bgo#736497).
  - Deprecate various obsolete macros.
  + build: Remove a non-existent file from EXTRA_DIST (bgo#735418).
  + compiler-flags: allow suppressing warnings.
  + code-coverage: Support lcov 1.11.
  + doc: Move doc/usage.txt to README and update.
  + make program_VERSION a local variable.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Read the dirlist file unconditionally.
  + compiler-flags: Replace deprecated AC_HELP_STRING with
    AS_HELP_STRING.
  + gnome-autogen.sh: Check for appdata-xml.m4 with APPDATA_XML.
  + Bugs fixed: bgo#726208, bgo#726892.
* Sat Nov 23 2013 dimstar@opensuse.org
- Replace gnome-doc-utils Requires with gnome-doc-utils-devel:
  gnome-autogen.sh wants gnome-doc-prepare to be present, which is
  in gnome-doc-utils-devel.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + compiler-flags:
  - Add a #serial line (bgo#707475).
  - Add an optional second argument for custom warnings
    (bgo#707475).
  + Run intltool before autoreconf so intltool.m4 is picked up by
    aclocal (bgo#705365).
  + gnome-autogen.sh:
  - run glib-gettexize if using GLib gettext.
  - Check only for autoreconf; autoconf, automake, libtool,
    gettext are already checked by autoreconf.
  - Do not use sed to get the AC_CONFIG_MACRO_DIR directory.
  - Create m4 directory if it doesnt exits.
  - Add support for automake 1.14.
  + Add support for lcov 1.10.
  + Other bugs fixed: bgo#699943
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + code coverage:
  - Quiet lcov and add extra ignore patterns
  - Relicense to LGPL-2.1+
  + Add more warnings to the default GNOME_COMPILE_WARNINGS
  + Add support for automake 1.13.
  + Finally and completely specify GPL-2.0+ as the license for
    gnome-common (as a collection of GPL-2.0+ and LGPL-2.1+ files).
    NOTE: the .spec file already used the previous assumption of
    GPL-2.0+ being the right license.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Add missing semicolons to omf_timestamp rule (bgo#685388).
* Sun Sep  9 2012 zaitor@opensuse.org
- Update to version 3.5.91:
  + Add code coverage support (bgo#606720).
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Add support for automake 1.12.
  + Fix bashishms (bgo#588020).
  + Do not call automake with --force (bgo#612329).
  + Fix srcdir!=builddir for scrollmaker (bgo#315320, bgo#409060).
  + Check for glibtoolize in gnome-autogen.sh.
  + Trace AC_CONFIG_SUBDIRS with autoconf.
- Drop gnome-common-am112.patch: fixed upstream.
* Wed May 30 2012 jengelh@inai.de
- Parallel build with %%_smp_mflags
- Add gnome-common-am112.patch: Add support for automake 1.12.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + No changes.
- Changes from version 3.4.0:
  + Update following move to deprecation attributes for libraries.
* Thu Dec 22 2011 vuntz@opensuse.org
- Own %%{_datadir}/aclocal to fix build without automake/autoconf.
* Fri Sep  9 2011 vuntz@opensuse.org
- Add yelp-tools Requires: it provides yelp.m4, which is checked
  for since 3.1.0.
* Wed Aug 17 2011 dimstar@opensuse.org
- Update to version 3.1.0:
  + gnome-autogen.sh:
  - Don't print terminal codes if stdin isn't a tty
  - Check for yelp.m4 with YELP_HELP_INIT
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 2.34.0:
  + Use dirname, instead of basename for finding srcdir.
  + Remove gnome1 cruft.
  + Mark GNOME_COMMON_INIT as deprecated.
* Sun Feb 13 2011 vuntz@opensuse.org
- Remove 2.x references in summaries and descriptions.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Support for automake 1.11
  + use AM_SILENT_RULES
- Drop gnome-common-automake-1.11.patch, upstream included.
* Fri Jun 26 2009 dominique-obs@leuenberger.net
- Add patch gnome-common-automake-1.11.patch to be compatible
  to automake 1.11
* Fri Mar 20 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Add more flags to DISABLE_DEPRECATED.
- Remove AutoReqProv: it's default now.
* Sun Jan 25 2009 vuntz@novell.com
- Add various Requires to make gnome-common work out of the box.
  Fix bnc#463104.
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Cosmetic version bump
* Tue Jan 29 2008 rodrigo@suse.de
- Update to version 2.20.0
* Wed Aug  1 2007 maw@suse.de
- Update to version 2.18.0
- Bugs (bugzilla.gnome.org) fixed: #377185, #360693, #377175,
  [#323868], #343441, #321860, #319496, and #305641.
- Works with automake 1.10, so drop gnome-autogen.diff.
* Wed Dec 13 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sat Oct 21 2006 schwab@suse.de
- Work around bogus version check.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Sep 20 2005 rodrigo@suse.de
- Update to version 2.12.0.
* Thu Aug  4 2005 sbrabec@suse.cz
- Updated to version 2.11.0.
* Mon Nov 22 2004 sbrabec@suse.cz
- Fixed gnome-autogen.sh for multi-component GNOME2_PATH.
  http://bugzilla.gnome.org/show_bug.cgi?id=159062
* Thu Nov 18 2004 gekker@suse.de
- Update to version 2.8.0
* Mon Aug 23 2004 ro@suse.de
- support automake 1.9 as well
* Wed Aug  4 2004 dobey@suse.de
- Add support for automake 1.8
* Mon Feb 23 2004 sbrabec@suse.cz
- Set owner to root, not bin.
* Thu Nov  6 2003 schwab@suse.de
- Fix directory permissions.
* Wed Oct  8 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 12 2003 sbrabec@suse.cz
- Fixed directory packaging.
- Package marked as noarch.
* Mon Sep  9 2002 kukuk@suse.de
- Remove all the not needed packages from neededforbuild
* Fri Jun 14 2002 ro@suse.de
- move last change to glib2 package
* Thu Jun 13 2002 ro@suse.de
- add gnome2.{sh,csh} to have /opt/gnome2/bin first in PATH
  on 7.3 and older distros
* Tue Apr 23 2002 ro@suse.de
- fix gnome1 macros for current autoconf (LIBOBJ usage)
* Tue Mar  5 2002 hhetter@suse.de
- shrink down #neededforbuild
* Thu Jan 17 2002 hhetter@suse.de
- prefix to /opt/gnome2
* Tue Jan  8 2002 hhetter@suse.de
- intial SuSE package for GNOME 2.0 platform
